clear

* Set your local directory here
capture cd "C:\Users\agooch\Dropbox\S_GoochHuberTrumpPaper\ReplicationArchive"

/*
// The "keep" line of code was already run on the original data file from CCES (see instructions for links and citation)
// The line of code is included below for accounting purposes
// We keep only the variables from the Common Content file that are used in our analysis
// The result is a reduced CCES data file before our analysis

keep pid7 votereg_post cc16_401 cc16_340a cc16_340e cc16_340d cc16_340a cc16_410a commonweight_post cc16_316 cc16_326 birthyr gender race faminc educ cc16_422e cc16_422f cc16_422c cc16_422d cc16_351b
*/

use "RawData\CCES2016_CommonContent.dta"

set more off

recode pid7 (1/3=-1) (4=0) (5/7=1) (8=0) (*=0), gen(DtoItoR_pid3)
label var DtoItoR_pid3 "Pid 3, -1=Dem/Lean, 1=Rep/Lean, 0=Indp/Dk"

recode pid7 (1/2=-1) (3/5=0) (6/7=1) (8=0) (*=0), gen(DtoItoR_altpid3)
label var DtoItoR_altpid3 "Pid 3, -1=Dem, 1=Rep, 0=Indp/Lean/Dk"

gen PID=pid7
replace PID=4 if PID==8 | PID==.
label value PID pid7
label var PID "PID"
tab PID, gen(piddum_)
drop piddum_4
label var PID "7 Point PID, with DK as 4"

// Are you registered? Restrict to people who are registered and answered turnout question
 
* Keep people who answered post question about being registered  
keep if votereg_post   == 1
* Must have answered turnout question
keep if cc16_401~=.
* Must place themselves ideologically on 7-point scale
drop if cc16_340a==. | cc16_340a==8

* Binary indicator--report voting
gen report_voting = cc16_401==5

// Ideology labels
foreach var of varlist cc16_340e cc16_340d cc16_340a {
	replace `var' = `var'-4 if `var' ~=8
	replace `var' = 5 if `var'==8
	replace `var' = 5 if `var'==.
}

label define ideolab -3 "V. Lib." -2 "Lib." -1 "S. Lib." 0 "Middle" 1 "S. Cons." 2 "Cons." 3 "V. Cons." 4 "" 5 "DK/Can't place"
label values cc16_340e ideolab
label values cc16_340d ideolab
label values cc16_340a ideolab
tab cc16_340a

// VOTER CHOICE

*Includes voting for other candidate
gen trump_voter = (cc16_410a ==1)
gen clinton_voter = (cc16_410a ==2)
gen clint_other_trump_voter = (cc16_410a ==1)*1 + (cc16_410a ==2)*-1 if report_voting==1 
label var clint_other_trump_voter "Among Voters, Clinton (-1) Trump (1) Other (0) Voter"

*includes voting for other candidate or not voted
gen clinton_otherornon_trump = (cc16_410a ==1)*1 + (cc16_410a ==2)*-1
label var clinton_otherornon_trump "Clinton (-1) Trump (1) or NotVote/Other (0)"
label define convt -1 "Clinton" 0 "Not Vote/Other" 1 "Trump"
label values clinton_otherornon_trump convt

*binary vote where Trump = 1 and Clinton = 0
gen binary_vote = .
replace binary_vote = 1 if trump_voter == 1
replace binary_vote = 0 if clinton_voter == 1

//TRUMP ideology placement

recode cc16_340e (-3/3=0) (5=1) (*=1), gen(cantplacetrump)
label var cantplacetrump "Can't place Trump's ideology"
recode cc16_340d (-3/3=0) (5=1) (*=1), gen(cantplaceclinton)
label var cantplaceclinton "Can't place Clinton's ideology"
gen cantplaceeither=max(cantplacetrump,cantplaceclinton)
label var cantplaceeither "Can't place Clinton or Trump's ideology"

label var cc16_340a "Own Ideo Placement"
label var cc16_340e "Trump Ideo Placement"
label var cc16_340d "Clinton Ideo Placement"

tab cc16_340e, gen(tid_)
tab cc16_340d, gen(cid_)
rename cc16_340a Ideology
tab Ideology, gen(ownideo_)
drop ownideo_4
rename Ideology ideo_own

rename cc16_340e ideo_trump
rename cc16_340d ideo_clinton

// Ideological distance to each candidate

gen dist_clinton = abs(ideo_clinton-ideo_own) if ideo_clinton~=5
label var dist_clinton "Ideological Distance to Clinton (0-6)"
gen dist_trump = abs(ideo_trump-ideo_own) if ideo_trump~=5
label var dist_trump "Ideological Distance to Trump (0-6)"

gen clintoncloser=0
label var clintoncloser "Clinton closer to own ideology (1=yes)"
gen trumpcloser=0
label var trumpcloser "Trump closer to own ideology (1=yes)"
replace clintoncloser = 1 if dist_clinton<dist_trump & dist_clinton~=. & dist_trump~=.
replace trumpcloser = 1 if dist_trump<dist_clinton & dist_clinton~=. & dist_trump~=.

gen howmuchclintoncloser=0
gen howmuchtrumpcloser=0
label var howmuchclintoncloser "How much Clinton closer than Trump (0 to 7)"
label var howmuchtrumpcloser "How much Trump closer than Trump (0 to 7)"

replace howmuchclintoncloser = dist_trump - dist_clinton if clintoncloser==1
replace howmuchtrumpcloser = dist_clinton - dist_trump if trumpcloser==1

//* FIGURE 1, BOTTOM PANEL MAIN RESULT *//

preserve

*replace dist_clinton = 8 if dist_clinton==.
replace dist_trump = 8 if dist_trump==.
label define dist 8 "Can't Place"
*label values dist_clinton dist
label values dist_trump dist
drop if dist_clinton==.
gen ct=commonweight_post

collapse (mean) clinton_otherornon_trump (sum) ct [aweight=commonweight_post], by(dist_clinton dist_trump)
table dist_clinton dist_trump, c(mean clinton_otherornon_trump)

gen label=string(dist_trump)
replace label = "X" if label=="8"

twoway (scatter clinton_otherornon_trump dist_clinton if dist_trump==0, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot)) (scatter clinton_otherornon_trump dist_clinton if dist_trump==1, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter clinton_otherornon_trump dist_clinton if dist_trump==2, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter clinton_otherornon_trump dist_clinton if dist_trump==3, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter clinton_otherornon_trump dist_clinton if dist_trump==4, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter clinton_otherornon_trump dist_clinton if dist_trump==5, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter clinton_otherornon_trump dist_clinton if dist_trump==6, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter clinton_otherornon_trump dist_clinton if dist_trump==8, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(gs8) msize(vlarge) lpattern(dash) ) if dist_clinton~=8, title("Panel B: 2016") xtitle("Perceived Ideological Distance to Democrat (Clinton)") xlabel(0(1)6) ytitle("Democratic-Other-Republican Vote" "(-1 Clinton, 0=Other, 1=Trump)") legend(cols(4) subtitle("Perceived Ideological Distance to Republican (Trump)")) legend(order(1 "0" 2 "1" 3 "2" 4 "3" 5 "4" 6 "5" 7 "6" 8 "X (Can't Place)")) yline(0) scheme(s1mono) name(F2Overall2016, replace)
graph export Figures\Figure1B_2016.pdf, replace
restore

//* TABLE 2, MAIN RESULT *//

qui if 1==1 {

gen e_est = ""
gen e_cand = ""
gen e_sub =""
gen e_year = 2016
foreach var of newlist e_avg_place e_n e_avg_placeD e_nD e_avg_placeI e_nI e_avg_placeR e_nR {
	gen `var' = .
	}
label var e_avg_place "Overall"
label var e_avg_placeD "Among Dems."
label var e_avg_placeI "Among Indp."
label var e_avg_placeR "Among Reps."
label var e_n "N"
label var e_nD "N"
label var e_nI "N"
label var e_nR "N"

* Ideological Placement, 2016

* Candidate ideological placement
replace e_est = "Ideological Placement Table 1A" in 1/4
local inobs=1

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Democrat" in `inobs'
	replace e_sub = "Can Place Candidate" in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceclinton==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Candidate" in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplacetrump==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_clinton [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1


	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_trump [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	}

list e_* in 1/4

preserve
keep in 1/4
keep e_*
save Tables\Table2A.dta, replace
restore

* Inability to Place Ideologically, 2016

* Candidate ideological placement
replace e_est = "Can't Place Ideologically Table 1B" in 5/8

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ cantplaceclinton [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceclinton [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceclinton [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceclinton [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ cantplacetrump [aweight=commonweight_post] 
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplacetrump [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplacetrump [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplacetrump [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place at least one candidate
	replace e_cand = "Democrat" in `inobs' 
	replace e_sub = "Can Place Other Candidate" in `inobs'
	summ cantplaceclinton [aweight=commonweight_post] if cantplacetrump==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceclinton [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceclinton [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceclinton [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1


	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Other Candidate" in `inobs'
	summ cantplacetrump [aweight=commonweight_post] if cantplaceclinton==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplacetrump [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplacetrump [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplacetrump [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	}

list e_* in 5/8

preserve
keep in 5/8
keep e_*
save Tables\Table2B.dta, replace
restore

//* SUPPORTING INFORMATION (APPENDIX) ANALYSIS USING 2016 DATA *//

*Code below creates a loop to create SI Table 2, 

//* SI TABLE 2 *//

* Which candidate is closer?

* Candidate ideological placement
replace e_est = "Closer to Candidate Table 2A" in 9/12

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Closer to Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ clintoncloser [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ clintoncloser [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ clintoncloser [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ clintoncloser [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Closer to Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ trumpcloser [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ trumpcloser [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ trumpcloser [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ trumpcloser [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Closer to Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ clintoncloser [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ clintoncloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ clintoncloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ clintoncloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Closer to Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ trumpcloser [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ trumpcloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ trumpcloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ trumpcloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
}
list e_* in 9/12

preserve
keep in 9/12
keep e_*
save Tables\SITable2A.dta, replace
restore

* Candidate ideological placement
replace e_est = "Distance to Candidate Table 2B" in 13/18

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Distance to Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplacetrump==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplacetrump==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Distance to Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
	
	*Given can't place other candidates
	replace e_cand = "Distance to Democrat" in `inobs' 
	replace e_sub = "Can't Place Other Candidate" in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0 & cantplacetrump==1
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0 & cantplacetrump==1 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0 & cantplacetrump==1 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_clinton [aweight=commonweight_post] if cantplaceclinton==0 & cantplacetrump==1 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Can't Place Other Candidate" in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceclinton==1 & cantplacetrump==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceclinton==1 & cantplacetrump==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceclinton==1 & cantplacetrump==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_trump [aweight=commonweight_post] if cantplaceclinton==1 & cantplacetrump==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
	
}

list e_* in 13/18

preserve
keep in 13/18
keep e_*
save Tables\SITable2B.dta, replace
restore

}

//* SI FIGURE 1 *//
* Spatial model of voting with distribution of votes for 2016

preserve
gen dem_dist_advantage = 0
replace dem_dist_advantage = howmuchtrumpcloser if trumpcloser==1
replace dem_dist_advantage = -howmuchclintoncloser if clintoncloser==1
replace dem_dist_advantage = . if cantplaceeither==1

local c0 = "red"
local c1 = "blue"
local c2 = "black"
keep if cantplaceclinton==0 & cantplacetrump==0
collapse (mean) trump_voter clinton_voter (count) numobs=trump_voter [aweight=commonweight_post], by(dem_dist_advantage)
label var numobs "Distribution of Votes"
label var trump_voter "Trump Voters"
label var clinton_voter "Clinton Voters"
label var dem_dist_advantage "Closer Candidate's Spatial Advantage"
summ numobs
replace numobs=numobs / (r(N)*r(mean))
twoway (scatter trump_voter dem_dist_advantage, xline(0) msymbol(Th) mcolor(`c0') ylabel(0(.2)1)) (scatter clinton_voter dem_dist_advantage, msymbol(Dh) mcolor(`c1' ))  (lpoly numobs dem_dist_advantage, yaxis(2)),  xlabel(-6  `" "Closer to"  "Clinton (-6)" "' 0 "Neither (0)" 6  `" "Closer to"  "Trump (6)" "')  ytitle("Proportion Voting for...") ytitle("Distribution of Respondents", axis(2)) ylabel(0(.02).14, axis(2)) legend(order(1 "Trump" 2 "Clinton")) note("Among those placing both candidates") name(F1Overall2016, replace)
graph export Figures\SIFigure1_2016.pdf, replace

restore


//* SI TABLE 7 *//
*This part of the code first creates columns 1-4
*Then, a loop creates columns 5-14
*All results are stored in an OUT file (SpatialbyPID2016) that can be converted to Excel


//* SI TABLE 7 COLUMNS 1 *//
*Spatial model with closer to candidate controls

preserve
drop if cantplacetrump==1 & cantplaceclinton==1
gen dem_dist_advantage = 0
replace dem_dist_advantage = howmuchtrumpcloser if trumpcloser==1
replace dem_dist_advantage = -howmuchclintoncloser if clintoncloser==1
rename dem_dist_advantage CloserCandSpatialAdv
tab CloserCandSpatialAdv, gen(ccsa_)
drop ccsa_7
label var ccsa_1 "Respondent 6 units closer to Clinton"
label var ccsa_2 "Respondent 5 units closer to Clinton"
label var ccsa_3 "Respondent 4 units closer to Clinton"
label var ccsa_4 "Respondent 3 units closer to Clinton"
label var ccsa_5 "Respondent 2 units closer to Clinton"
label var ccsa_6 "Respondent 1 unit closer to Clinton"

label var ccsa_8 "Respondent 1 unit closer to Trump"
label var ccsa_9 "Respondent 2 units closer to Trump"
label var ccsa_10 "Respondent 3 units closer to Trump"
label var ccsa_11 "Respondent 4 units closer to Trump"
label var ccsa_12 "Respondent 5 units closer to Trump"
label var ccsa_13 "Respondent 6 units closer to Trump"

regress clinton_otherornon_trump ccsa_* cantplacetrump cantplaceclinton [aweight=commonweight_post], robust
summ clinton_otherornon_trump if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016.out, ctitle("2016 Pooled") se tdec(3) replace bracket

//* SI TABLE 7 COLUMNS 2 *// 
*Spatial model with closer to candidate controls and partisanship

regress clinton_otherornon_trump ccsa_* piddum_* cantplacetrump cantplaceclinton [aweight=commonweight_post]
summ clinton_otherornon_trump if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016.out, ctitle("2016 Adding Indicators for Partisanship") se tdec(3) append bracket

//* SI TABLE 7 COLUMNS 3 *// 
*Spatial model with closer to candidate controls, partisanship, and ideology

regress clinton_otherornon_trump ccsa_* piddum_* ownideo_* cantplacetrump cantplaceclinton [aweight=commonweight_post]
summ clinton_otherornon_trump if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016.out, ctitle("2016 Adding Indicators for Ideology") se tdec(3) append bracket


//* SI TABLE 7 COLUMNS 4 *// 
*Spatial model with closer to candidate controls, partisanship, ideology, and 2012 vote choice

gen didntvote2012=1
replace didntvote2012=0 if cc16_316==4
label var didntvote2012 "Didn't vote 2012"
gen vote2012dem=(didntvote2012==0 & cc16_326==1)
gen vote2012rep=(didntvote2012==0 & cc16_326==2)
label var vote2012dem "Voted Obama 2012"
label var vote2012rep "Voted Romney 2012"

regress clinton_otherornon_trump ccsa_* piddum_* ownideo_* cantplacetrump cantplaceclinton vote2012dem vote2012rep [aweight=commonweight_post]
summ clinton_otherornon_trump if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016.out, ctitle("2016 Adding 2012 Vote") se tdec(3) append bracket

//* SI TABLE 7 COLUMNS 5-7 *// 
*Spatial model stratified by party ID

forvalues pidctr = -1(1)1 {

	if `pidctr'==-1 {
		local templabel="Democrats"
	}
	else if `pidctr'==0 {
		local templabel="Independents"
	}
	else {
		local templabel="Republicans"
	}

	regress clinton_otherornon_trump ccsa_* cantplacetrump cantplaceclinton ownideo_*  [aweight=commonweight_post] if DtoItoR_pid3==`pidctr'
	summ clinton_otherornon_trump if e(sample)
	local outmean= r(mean)
	summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
	local cpcmean= r(mean)
	summ cantplacetrump [aweight=commonweight_post]  if e(sample)
	local cptmean= r(mean)
	outreg2 using Tables\SpatialbyPID2016.out, ctitle("2016 `templabel'") se tdec(3) append bracket
	//se bracket rdec(3) tdec(3) addstat("Outcome mean",`outmean',"Prop. Can't Place Clinton",`cpcmean',"Prop. Can't Place Trump",`cptmean') adec(3) append
}

//* SI TABLE 7 COLUMNS 8-14 *// 
*Spatial model stratified by party ID and ideology combinations

forvalues ideoctr = -3(1)3 {

	local templabel : label (ideo_own) `ideoctr'

	regress clinton_otherornon_trump ccsa_* cantplacetrump cantplaceclinton piddum_* [aweight=commonweight_post] if ideo_own==`ideoctr'
	summ clinton_otherornon_trump if e(sample)
	local outmean= r(mean)
	summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
	local cpcmean= r(mean)
	summ cantplacetrump [aweight=commonweight_post]  if e(sample)
	local cptmean= r(mean)
	outreg2 using Tables\SpatialbyPID2016.out, ctitle("Ideology=`templabel' with PID") se tdec(3) append bracket
	//se bracket rdec(3) tdec(3) addstat("Outcome mean",`outmean',"Prop. Can't Place Clinton",`cpcmean',"Prop. Can't Place Trump",`cptmean') adec(3) append
	
}

restore



//* SI TABLE 8 *//
*Exact same as SI Table 7 but with a binary dependent variable (voting Clinton or Trump only)
*This part of the code first creates columns 1-4
*Then, a loop creates columns 5-14
*All results are stored in an OUT file (SpatialbyPID2016_binary) that can be converted to Excel


//* SI TABLE 8 COLUMNS 1 *//
*Spatial model with closer to candidate controls

preserve
drop if cantplacetrump==1 & cantplaceclinton==1
gen dem_dist_advantage = 0
replace dem_dist_advantage = howmuchtrumpcloser if trumpcloser==1
replace dem_dist_advantage = -howmuchclintoncloser if clintoncloser==1
rename dem_dist_advantage CloserCandSpatialAdv
tab CloserCandSpatialAdv, gen(ccsa_)
drop ccsa_7
label var ccsa_1 "Respondent 6 units closer to Clinton"
label var ccsa_2 "Respondent 5 units closer to Clinton"
label var ccsa_3 "Respondent 4 units closer to Clinton"
label var ccsa_4 "Respondent 3 units closer to Clinton"
label var ccsa_5 "Respondent 2 units closer to Clinton"
label var ccsa_6 "Respondent 1 unit closer to Clinton"

label var ccsa_8 "Respondent 1 unit closer to Trump"
label var ccsa_9 "Respondent 2 units closer to Trump"
label var ccsa_10 "Respondent 3 units closer to Trump"
label var ccsa_11 "Respondent 4 units closer to Trump"
label var ccsa_12 "Respondent 5 units closer to Trump"
label var ccsa_13 "Respondent 6 units closer to Trump"

regress binary_vote ccsa_* cantplacetrump cantplaceclinton [aweight=commonweight_post], robust
summ binary_vote if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016_binary.out, ctitle("2016 Pooled") se tdec(3) replace bracket

//* SI TABLE 8 COLUMNS 2 *// 
*Spatial model with closer to candidate controls and partisanship

regress binary_vote ccsa_* piddum_* cantplacetrump cantplaceclinton [aweight=commonweight_post]
summ binary_vote if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016_binary.out, ctitle("2016 Adding Indicators for Partisanship") se tdec(3) append bracket

//* SI TABLE 8 COLUMNS 3 *// 
*Spatial model with closer to candidate controls, partisanship, and ideology

regress binary_vote ccsa_* piddum_* ownideo_* cantplacetrump cantplaceclinton [aweight=commonweight_post]
summ binary_vote if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016_binary.out, ctitle("2016 Adding Indicators for Ideology") se tdec(3) append bracket


//* SI TABLE 8 COLUMNS 4 *// 
*Spatial model with closer to candidate controls, partisanship, ideology, and 2012 vote choice

*2012 vote choice, indicators for each candidate
gen didntvote2012=1
replace didntvote2012=0 if cc16_316==4
label var didntvote2012 "Didn't vote 2012"
gen vote2012dem=(didntvote2012==0 & cc16_326==1)
gen vote2012rep=(didntvote2012==0 & cc16_326==2)
label var vote2012dem "Voted Obama 2012"
label var vote2012rep "Voted Romney 2012"

regress binary_vote ccsa_* piddum_* ownideo_* cantplacetrump cantplaceclinton vote2012dem vote2012rep [aweight=commonweight_post]
summ binary_vote if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016_binary.out, ctitle("2016 Adding 2012 Vote") se tdec(3) append bracket

// se bracket rdec(3) tdec(3) addstat("Outcome mean",`outmean',"Prop. Can't Place Clinton",`cpcmean',"Prop. Can't Place Trump",`cptmean') adec(3) append

forvalues pidctr = -1(1)1 {

	if `pidctr'==-1 {
		local templabel="Democrats"
	}
	else if `pidctr'==0 {
		local templabel="Independents"
	}
	else {
		local templabel="Republicans"
	}

	regress binary_vote ccsa_* cantplacetrump cantplaceclinton ownideo_*  [aweight=commonweight_post] if DtoItoR_pid3==`pidctr'
	summ binary_vote if e(sample)
	local outmean= r(mean)
	summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
	local cpcmean= r(mean)
	summ cantplacetrump [aweight=commonweight_post]  if e(sample)
	local cptmean= r(mean)
	outreg2 using Tables\SpatialbyPID2016_binary.out, ctitle("2016 `templabel'") se tdec(3) append bracket
	//se bracket rdec(3) tdec(3) addstat("Outcome mean",`outmean',"Prop. Can't Place Clinton",`cpcmean',"Prop. Can't Place Trump",`cptmean') adec(3) append
}

forvalues ideoctr = -3(1)3 {

	local templabel : label (ideo_own) `ideoctr'

	regress binary_vote ccsa_* cantplacetrump cantplaceclinton piddum_* [aweight=commonweight_post] if ideo_own==`ideoctr'
	summ binary_vote if e(sample)
	local outmean= r(mean)
	summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
	local cpcmean= r(mean)
	summ cantplacetrump [aweight=commonweight_post]  if e(sample)
	local cptmean= r(mean)
	outreg2 using Tables\SpatialbyPID2016_binary.out, ctitle("Ideology=`templabel' with PID") se tdec(3) append bracket
	//se bracket rdec(3) tdec(3) addstat("Outcome mean",`outmean',"Prop. Can't Place Clinton",`cpcmean',"Prop. Can't Place Trump",`cptmean') adec(3) append
	
}

restore


//* SI TABLE 9  *// 
*Spatial model with as many controls as possible (closer to candidate, party, ideology, 2012 vote choice, age, race, gender, education, income, TPP roll call, four race questions
*Results are stored in an OUT file called SpatialbyPID2016_fullcontrol

tab birthyr
gen age = 2017 - birthyr
label var age "Age (calculated from asking year of birth)"
tab age

gen female = 0
replace female = 1 if gender ==2

gen black = 0
replace black = 1 if race == 2

gen other = 0
replace other = 1 if race == 4 | race == 5 |race == 6 | race == 7 | race == 8

gen Hispanic = 0
replace Hispanic = 1 if race == 3

summ faminc if faminc !=18
replace faminc=6.75 if faminc==18

// code racial questions in direction of expected trump support
tab cc16_422e
gen fearful_races = cc16_422e
replace fearful_races = 1 if cc16_422e == 5
replace fearful_races = 2 if cc16_422e == 4
replace fearful_races = 3 if cc16_422e == 3
replace fearful_races = 4 if cc16_422e == 2
replace fearful_races = 5 if cc16_422e == 1

tab cc16_422f
gen rare_probs_rare = cc16_422f
replace rare_probs_rare = 1 if cc16_422f == 5
replace rare_probs_rare = 2 if cc16_422f == 4
replace rare_probs_rare = 3 if cc16_422f == 3
replace rare_probs_rare = 4 if cc16_422f == 2
replace rare_probs_rare = 5 if cc16_422f == 1

gen racism_exists = cc16_422c

gen whites_advantaged = cc16_422d

drop if cantplacetrump==1 & cantplaceclinton==1
gen dem_dist_advantage = 0
replace dem_dist_advantage = howmuchtrumpcloser if trumpcloser==1
replace dem_dist_advantage = -howmuchclintoncloser if clintoncloser==1
rename dem_dist_advantage CloserCandSpatialAdv
tab CloserCandSpatialAdv, gen(ccsa_)
drop ccsa_7
label var ccsa_1 "Respondent 6 units closer to Clinton"
label var ccsa_2 "Respondent 5 units closer to Clinton"
label var ccsa_3 "Respondent 4 units closer to Clinton"
label var ccsa_4 "Respondent 3 units closer to Clinton"
label var ccsa_5 "Respondent 2 units closer to Clinton"
label var ccsa_6 "Respondent 1 unit closer to Clinton"

label var ccsa_8 "Respondent 1 unit closer to Trump"
label var ccsa_9 "Respondent 2 units closer to Trump"
label var ccsa_10 "Respondent 3 units closer to Trump"
label var ccsa_11 "Respondent 4 units closer to Trump"
label var ccsa_12 "Respondent 5 units closer to Trump"
label var ccsa_13 "Respondent 6 units closer to Trump"

*2012 vote choice, indicators for each candidate
gen didntvote2012=1
replace didntvote2012=0 if cc16_316==4
label var didntvote2012 "Didn't vote 2012"
gen vote2012dem=(didntvote2012==0 & cc16_326==1)
gen vote2012rep=(didntvote2012==0 & cc16_326==2)
label var vote2012dem "Voted Obama 2012"
label var vote2012rep "Voted Romney 2012"

*TPP
gen TTP_rollcall = .
replace TTP_rollcall = 1 if cc16_351b == 1
replace TTP_rollcall = 0 if cc16_351b == 2

*SI TABLE 9
regress clinton_otherornon_trump ccsa_* piddum_* ownideo_* cantplacetrump cantplaceclinton vote2012dem vote2012rep age female educ black Hispanic other faminc TTP_rollcall fearful_races ///
rare_probs_rare racism_exists whites_advantaged [aweight=commonweight_post]
summ clinton_otherornon_trump if e(sample)
local outmean= r(mean)
summ cantplaceclinton [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacetrump [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialbyPID2016_fullcontrol.out, ctitle("2016 Adding 2012 Vote") se tdec(3) append bracket

