clear

* Set your local directory here
capture cd "C:\Users\agooch\Dropbox\S_GoochHuberTrumpPaper\ReplicationArchive"

/*
// The "keep" line of code was already run on the original data file from CCES (see instructions for links and citation)
// The line of code is included below for accounting purposes
// We keep only the variables from the Common Content file that are used in our analysis
// The result is a reduced CCES data file before our analysis

//keep V201 CC307a V256 CC403 CC317a CC317h CC317g CC327 CC335bush
*/

use "RawData\CCES2008_CommonContent.dta"

*change weight label to be same as in 2016
rename V201 commonweight_post

set more off

rename CC307a pid7
recode pid7 (1/3=-1) (4=0) (5/7=1) (8=0) (*=0), gen(DtoItoR_pid3)
label var DtoItoR_pid3 "Pid 3, -1=Dem/Lean, 1=Rep/Lean, 0=Indp/Dk"

recode pid7 (1/2=-1) (3/5=0) (6/7=1) (8=0) (*=0), gen(DtoItoR_altpid3)
label var DtoItoR_pid3 "Pid 3, -1=Dem, 1=Rep, 0=Indp/Lean/Dk"

gen PID=pid7
replace PID=4 if PID==8 | PID==.
label value PID pid7
label var PID "PID"
tab PID, gen(piddum_)
drop piddum_4
label var PID "7 Point PID, with DK as 4"

// Are you registered? Restrict to people who are registered and answered turnout question

* Keep people who answered post question about being registered
keep if V256 == 1
* Must have answered turnout question
keep if CC403~=.
* Must have placed themselves on the ideology scale
keep if CC317a ~=.

* Binary indicator--report voting
gen report_voting = CC403==5

// Ideology labels + recode into 8 point frome 0 to 100 scale
recode CC317a (0/14=-3) (15/28=-2) (29/42=-1) (43/57=0) (58/71=1) (72/85=2) (86/100=3) (*=5)
recode CC317h (0/14=-3) (15/28=-2) (29/42=-1) (43/57=0) (58/71=1) (72/85=2) (86/100=3) (*=5)
recode CC317g (0/14=-3) (15/28=-2) (29/42=-1) (43/57=0) (58/71=1) (72/85=2) (86/100=3) (*=5)

label define ideolab -3 "V. Lib." -2 "Lib." -1 "S. Lib." 0 "Middle" 1 "S. Cons." 2 "Cons." 3 "V. Cons." 4 "" 5 "DK/Can't place"
label values CC317a ideolab // self
label values CC317h ideolab // obama
label values CC317g ideolab // mccain
tab CC317a


// VOTERS (note 2008 survey asked vote choice, even for people who didn't vote)
gen mccain_voter = (CC327 ==1) & report_voting==1
gen obama_voter = (CC327 ==2) & report_voting==1 
gen obama_other_mccain_voter = (CC327 ==1)*1 + (CC327 ==2)*-1 if report_voting==1 
label var obama_other_mccain_voter "Among Voters, Obama (-1) McCain (1) Other (0) Voter"

gen obama_otherornon_mccain = (CC327 ==1)*1 + (CC327 ==2)*-1
label var obama_otherornon_mccain "Obama (-1) McCain (1) or NotVote/Other (0)"
label define convt -1 "Obama" 0 "Not Vote/Other" 1 "McCain"
label values obama_otherornon_mccain convt

//TRUMP ideology placement
recode CC317g (-3/3=0) (5=1) (*=1), gen(cantplacemccain)
label var cantplacemccain "Can't place McCain's ideology"
recode CC317h (-3/3=0) (5=1) (*=1), gen(cantplaceobama)
label var cantplaceobama "Can't place Obama's ideology"
gen cantplaceeither=max(cantplacemccain,cantplaceobama)
label var cantplaceeither "Can't place Obama or McCain's ideology"

label var CC317a "Own Ideo Placement"
label var CC317g "McCain Ideo Placement"
label var CC317h "Obama Ideo Placement"

tab CC317g, gen(tid_)
tab CC317h, gen(cid_)
rename CC317a Ideology
tab Ideology, gen(ownideo_)
rename Ideology ideo_own
drop ownideo_4

rename CC317g ideo_mccain
rename CC317h ideo_obama

mean cantplaceobama
mean cantplacemccain

// Ideological distance to each candidate

gen dist_obama = abs(ideo_obama-ideo_own) if ideo_obama~=5
label var dist_obama "Ideological Distance to Obama (0-6)"
gen dist_mccain = abs(ideo_mccain-ideo_own) if ideo_mccain~=5
label var dist_mccain "Ideological Distance to McCain (0-6)"

gen obamacloser=0
label var obamacloser "Obama closer to own ideology (1=yes)"
gen mccaincloser=0
label var mccaincloser "McCain closer to own ideology (1=yes)"
replace obamacloser = 1 if dist_obama<dist_mccain & dist_obama~=. & dist_mccain~=.
replace mccaincloser = 1 if dist_mccain<dist_obama & dist_obama~=. & dist_mccain~=.

gen howmuchobamacloser=0
gen howmuchmccaincloser=0
label var howmuchobamacloser "How much Obama closer than McCain (0 to 7)"
label var howmuchmccaincloser "How much McCain closer than McCain (0 to 7)"

replace howmuchobamacloser = dist_mccain - dist_obama if obamacloser==1
replace howmuchmccaincloser = dist_obama - dist_mccain if mccaincloser==1


//* FIGURE 1, TOP PANEL MAIN RESULT *//

preserve

replace dist_mccain= 8 if dist_mccain==.
label define dist 8 "Can't Place"
label values dist_mccain dist
drop if dist_obama==.
gen ct=commonweight_post
collapse (mean) obama_otherornon_mccain (sum) ct [aweight=commonweight_post], by(dist_obama dist_mccain)
table dist_obama dist_mccain, c(mean obama_otherornon_mccain)

gen label=string(dist_mccain)
replace label = "X" if label=="8"
*Makethe plot
twoway (scatter obama_otherornon_mccain dist_obama if dist_mccain==0, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot)) (scatter obama_otherornon_mccain dist_obama if dist_mccain==1, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter obama_otherornon_mccain dist_obama if dist_mccain==2, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter obama_otherornon_mccain dist_obama if dist_mccain==3, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter obama_otherornon_mccain dist_obama if dist_mccain==4, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter obama_otherornon_mccain dist_obama if dist_mccain==5, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter obama_otherornon_mccain dist_obama if dist_mccain==6, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(black) msize(vlarge) lpattern(dot) ) (scatter obama_otherornon_mccain dist_obama if dist_mccain==8, connect(l) mlabel(label) mlabposition(0) mlabsize(medium) mlabcolor(white) msymbol(O) mcolor(gs8) msize(vlarge) lpattern(dash) ) if dist_obama~=8, title("Panel A: 2008") xtitle("Perceived Ideological Distance to Democrat (Obama)") xlabel(0(1)6) ytitle("Democratic-Other-Republican Vote" "(-1 Obama, 0=Other, 1=McCain)") legend(cols(4) subtitle("Perceived Ideological Distance to Republican (McCain)")) legend(order(1 "0" 2 "1" 3 "2" 4 "3" 5 "4" 6 "5" 7 "6" 8 "X (Can't Place)")) yline(0) scheme(s1mono) name(F2Overall2008, replace)
graph export Figures\Figure1A_2008.pdf, replace
restore




//* TABLE 2, MAIN RESULT *//
* Must run the do file 01_2016CCES first because this code adds to TABLE2A and TABLE2B datasets
* Then, 03_BuildTables combines 2008 and 2016


if 1==1 {


gen e_est = ""
gen e_cand = ""
gen e_sub =""
gen e_year = 2008
foreach var of newlist e_avg_place e_n e_avg_placeD e_nD e_avg_placeI e_nI e_avg_placeR e_nR {
	gen `var' = .
	}
label var e_avg_place "Overall"
label var e_avg_placeD "Among Dems."
label var e_avg_placeI "Among Indp."
label var e_avg_placeR "Among Reps."
label var e_n "N"
label var e_nD "N"
label var e_nI "N"
label var e_nR "N"

* Ideological Placement, 2008

* Candidate ideological placement
replace e_est = "Ideological Placement Table 1A" in 1/4
local inobs=1

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Democrat" in `inobs'
	replace e_sub = "Can Place Candidate" in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Candidate" in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplacemccain==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1


	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_mccain [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	}

list e_* in 1/4

preserve
keep in 1/4
keep e_*
append using Tables\Table2A.dta
save Tables\Table2A.dta, replace
restore

* Inability to Place Ideologically, 2008

* Candidate ideological placement
replace e_est = "Can't Place Ideologically Table 1B" in 5/8

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ cantplaceobama [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ cantplacemccain [aweight=commonweight_post] 
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplacemccain [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplacemccain [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplacemccain [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place at least one candidate
	replace e_cand = "Democrat" in `inobs' 
	replace e_sub = "Can Place Other Candidate" in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplacemccain==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1


	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Other Candidate" in `inobs'
	summ cantplacemccain [aweight=commonweight_post] if cantplaceobama==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplacemccain [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplacemccain [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplacemccain [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	}

list e_* in 5/8

preserve

keep in 5/8
keep e_*
append using Tables\Table2B.dta
save Tables\Table2B.dta, replace
restore



//* SUPPORTING INFORMATION (APPENDIX) ANALYSIS USING 2016 DATA *//

*Code below creates a loop to create SI Table 2, 

//* SI TABLE 2 *//

* Which candidate is closer?

* Candidate ideological placement
replace e_est = "Closer to Candidate Table 2A" in 9/12

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Closer to Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ obamacloser [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Closer to Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ mccaincloser [aweight=commonweight_post] 
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ mccaincloser [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ mccaincloser [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ mccaincloser [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Closer to Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Closer to Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ mccaincloser [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ mccaincloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ mccaincloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ mccaincloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
}
list e_* in 9/12

preserve
keep in 9/12
keep e_*
append using Tables\SITable2A.dta
save Tables\SITable2A.dta, replace
restore

* Candidate ideological placement
replace e_est = "Distance to Candidate Table 2B" in 13/18

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Distance to Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplacemccain==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplacemccain==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Distance to Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
	
	*Given can't place other candidates
	replace e_cand = "Distance to Democrat" in `inobs' 
	replace e_sub = "Can't Place Other Candidate" in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplacemccain==1
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplacemccain==1 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplacemccain==1 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplacemccain==1 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Can't Place Other Candidate" in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceobama==1 & cantplacemccain==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceobama==1 & cantplacemccain==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceobama==1 & cantplacemccain==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_mccain [aweight=commonweight_post] if cantplaceobama==1 & cantplacemccain==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
	
}

list e_* in 13/18

preserve
keep in 13/18
keep e_*
append using Tables\SITable2B.dta
save Tables\SITable2B.dta, replace
restore

}



//* SI FIGURE 2 *//
* Spatial model of voting with distribution of votes for 2008

preserve
gen dem_dist_advantage = 0
replace dem_dist_advantage = howmuchmccaincloser if mccaincloser==1
replace dem_dist_advantage = -howmuchobamacloser if obamacloser==1
replace dem_dist_advantage = . if cantplaceeither==1

local c0 = "red"
local c1 = "blue"
local c2 = "black"
*keep if cantplacemccain==0 & cantplaceobama==0
collapse (mean) mccain_voter obama_voter (count) numobs=mccain_voter [aweight=commonweight_post], by(dem_dist_advantage)
label var numobs "Distribution of Votes"
label var mccain_voter "McCain Voters"
label var obama_voter "Obama Voters"
label var dem_dist_advantage "Closer Candidate's Spatial Advantage"
summ numobs
replace numobs=numobs / (r(N)*r(mean))
twoway (scatter mccain_voter dem_dist_advantage, xline(0) msymbol(Th) mcolor(`c0') ylabel(0(.2)1)) (scatter obama_voter dem_dist_advantage, msymbol(Dh) mcolor(`c1' ))  (lpoly numobs dem_dist_advantage, yaxis(2)), title("Panel A: 2008")  xlabel(-6  `" "Closer to"  "Obama (-6)" "' 0 "Neither (0)" 6  `" "Closer to"  "McCain (6)" "')  ytitle("Proportion Voting for...") ytitle("Distribution of Respondents", axis(2)) ylabel(0(.02).14, axis(2)) legend(order(1 "McCain" 2 "Obama")) note("Among those placing both candidates") name(F1Overall2008, replace)
graph export Figures\SIFigure1A_2008.pdf, replace

restore


* SI Appendix table 6 columns 1-3 -> simple spatial models

reg obama_otherornon_mccain obamacloser mccaincloser 
outreg2 using Tables\Basic_Spatial2008.out, ctitle("Binary Indicators for Spatially Closer") se tdec(3) replace bracket

reg obama_otherornon_mccain dist_obama dist_mccain
outreg2 using Tables\Basic_Spatial2008.out, ctitle("Distance to Each Candidate") se tdec(3) append bracket

reg obama_otherornon_mccain obamacloser mccaincloser dist_obama dist_mccain
outreg2 using Tables\Basic_Spatial2008.out, ctitle("Indicators and Distance") se tdec(3) append bracket
mean obama_otherornon_mccain

//* SI TABLE 10 *//
*This part of the code first creates columns 1-4
*Then, a loop creates columns 5-14
*All results are stored in an OUT file (SpatialbyPID2008) that can be converted to Excel


//* SI TABLE 10 COLUMNS 1 *//
*Spatial model with closer to candidate controls
preserve

gen dem_dist_advantage = 0
replace dem_dist_advantage = howmuchmccaincloser if mccaincloser==1
replace dem_dist_advantage = -howmuchobamacloser if obamacloser==1
rename dem_dist_advantage CloserCandSpatialAdv
tab CloserCandSpatialAdv, gen(ccsa_)
drop ccsa_7
label var ccsa_1 "Respondent 6 units closer to Clinton"
label var ccsa_2 "Respondent 5 units closer to Clinton"
label var ccsa_3 "Respondent 4 units closer to Clinton"
label var ccsa_4 "Respondent 3 units closer to Clinton"
label var ccsa_5 "Respondent 2 units closer to Clinton"
label var ccsa_6 "Respondent 1 unit closer to Clinton"

label var ccsa_8 "Respondent 1 unit closer to Trump"
label var ccsa_9 "Respondent 2 units closer to Trump"
label var ccsa_10 "Respondent 3 units closer to Trump"
label var ccsa_11 "Respondent 4 units closer to Trump"
label var ccsa_12 "Respondent 5 units closer to Trump"
label var ccsa_13 "Respondent 6 units closer to Trump"


regress obama_otherornon_mccain ccsa_* cantplacemccain cantplaceobama [aweight=commonweight_post], robust
summ obama_otherornon_mccain if e(sample)
local outmean= r(mean)
summ cantplaceobama [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacemccain [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialByPID2008.out, ctitle("2008 Pooled") se tdec(3) replace bracket


//* SI TABLE 10 COLUMNS 2 *// 
*Spatial model with closer to candidate controls and partisanship

regress obama_otherornon_mccain ccsa_* piddum_* cantplacemccain cantplaceobama [aweight=commonweight_post]
summ obama_otherornon_mccain if e(sample)
local outmean= r(mean)
summ cantplaceobama [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacemccain [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialByPID2008.out, ctitle("2008 Adding Indicators for Partisanship") se tdec(3) append bracket

//* SI TABLE 10 COLUMNS 3 *// 
*Spatial model with closer to candidate controls, partisanship, and ideology

regress obama_otherornon_mccain ccsa_* piddum_* ownideo_* cantplacemccain cantplaceobama [aweight=commonweight_post]
summ obama_otherornon_mccain if e(sample)
local outmean= r(mean)
summ cantplaceobama [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacemccain [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialByPID2008.out, ctitle("2008 Adding Indicators for Ideology") se tdec(3) append bracket

//* SI TABLE 10 COLUMNS 4 *// 
*Spatial model with closer to candidate controls, partisanship, ideology, and GWB approval (as a proxy for past vote)

tab CC335bush
gen bush_approval = CC335bush
replace bush_approval = . if CC335bush ==5
replace bush_approval = 4 if CC335bush ==1
replace bush_approval = 3 if CC335bush ==2
replace bush_approval = 2 if CC335bush ==3
replace bush_approval = 1 if CC335bush ==4

regress obama_otherornon_mccain ccsa_* piddum_* ownideo_* cantplacemccain cantplaceobama bush_approval [aweight=commonweight_post]
summ obama_otherornon_mccain if e(sample)
local outmean= r(mean)
summ cantplaceobama [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacemccain [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialByPID2008.out, ctitle("2008 Adding George Bush Approval") se tdec(3) append bracket


//* SI TABLE 10 COLUMNS 5-7 *// 
*Spatial model stratified by party ID

regress obama_otherornon_mccain ccsa_* cantplacemccain cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3==-1
summ obama_otherornon_mccain if e(sample)
local outmean= r(mean)
summ cantplaceobama [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacemccain [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialByPID2008.out, ctitle("2008 Democrats") se tdec(3) append bracket

regress obama_otherornon_mccain ccsa_* cantplacemccain cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3==0
summ obama_otherornon_mccain if e(sample)
local outmean= r(mean)
summ cantplaceobama [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacemccain [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialByPID2008.out, ctitle("2008 Independents") se tdec(3) append bracket

regress obama_otherornon_mccain ccsa_* cantplacemccain cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3==1
summ obama_otherornon_mccain if e(sample)
local outmean= r(mean)
summ cantplaceobama [aweight=commonweight_post]  if e(sample)
local cpcmean= r(mean)
summ cantplacemccain [aweight=commonweight_post]  if e(sample)
local cptmean= r(mean)
outreg2 using Tables\SpatialByPID2008.out, ctitle("2008 Republicans") se tdec(3) append bracket


//* SI TABLE 10 COLUMNS 8-14 *// 
*Spatial model stratified by party ID and ideology combinations

forvalues ideoctr = -3(1)3 {

	local templabel : label (ideo_own) `ideoctr'

	regress obama_otherornon_mccain ccsa_* cantplacemccain cantplaceobama piddum_* [aweight=commonweight_post] if ideo_own==`ideoctr'
	summ obama_otherornon_mccain if e(sample)
	local outmean= r(mean)
	summ cantplaceobama [aweight=commonweight_post]  if e(sample)
	local cpcmean= r(mean)
	summ cantplacemccain [aweight=commonweight_post]  if e(sample)
	local cptmean= r(mean)
	outreg2 using Tables\SpatialByPID2008.out, ctitle("Ideology=`templabel' with PID") se tdec(3) append bracket
}





restore
