clear

* Set your local directory here
capture cd "C:\Users\agooch\Dropbox\S_GoochHuberTrumpPaper\ReplicationArchive"

/*
// The "keep" line of code was already run on the original data file from CCES (see instructions for links and citation)
// The line of code is included below for accounting purposes
// We keep only the variables from the Common Content file that are used in our analysis
// The result is a reduced CCES data file before our analysis

keep pid7 votereg CC401 CC401 CC334D CC334C CC334A CC410a V103
*/

use "RawData\CCES2012_CommonContent.dta"
 
set more off

recode pid7 (1/3=-1) (4=0) (5/7=1) (8=0) (*=0), gen(DtoItoR_pid3)
label var DtoItoR_pid3 "Pid 3, -1=Dem/Lean, 1=Rep/Lean, 0=Indp/Dk"

recode pid7 (1/2=-1) (3/5=0) (6/7=1) (8=0) (*=0), gen(DtoItoR_altpid3)
label var DtoItoR_pid3 "Pid 3, -1=Dem, 1=Rep, 0=Indp/Lean/Dk"

gen PID=pid7    
replace PID=4 if PID==8
label value PID pid7
label var PID "PID"
tab PID, gen(piddum_)
drop piddum_4
label var PID "7 Point PID, with DK as 4"

// Are you registered? Restrict to people who are registered and answered turnout question

* Keep people who answered post question about being registered
keep if votereg   == 1
* Must have answered turnout question
keep if CC401~=.

* Binary indicator--report voting
gen report_voting = CC401==5


* Must place themselves ideologically on 7-point scale
drop if CC334A==. | CC334A==8


//label var CC334A "Own Ideo Placement"
//label var CC334D "Romney Ideo Placement"
//label var CC334C "Obama Ideo Placement"


// Ideology labels
foreach var of varlist CC334D CC334C CC334A {
	replace `var' = `var'-4 if `var' ~=8
	replace `var' = 5 if `var'==8
	replace `var' = 5 if `var'==.
}

label define ideolab -3 "V. Lib." -2 "Lib." -1 "S. Lib." 0 "Middle" 1 "S. Cons." 2 "Cons." 3 "V. Cons." 4 "" 5 "DK/Can't place"
label values CC334D ideolab
label values CC334C ideolab
label values CC334A ideolab
tab CC334A

// VOTER CHOICE

gen romney_voter = (CC410a ==2)
gen obama_voter = (CC410a ==1)
gen obama_other_romney_voter = (CC410a ==2)*1 + (CC410a ==1)*-1 if report_voting==1 
label var obama_other_romney_voter "Among Voters, Obama (-1) Romney (1) Other (0) Voter"

gen obama_otherornon_romney = (CC410a ==2)*1 + (CC410a ==1)*-1
label var obama_otherornon_romney "Obama (-1) Romney (1) or NotVote/Other (0)"
label define convt -1 "Obama" 0 "Not Vote/Other" 1 "Romney"
label values obama_otherornon_romney convt

//CANDIDATE ideology placement

recode CC334D (-3/3=0) (5=1) (*=1), gen(cantplaceromney)
label var cantplaceromney "Can't place Romney's ideology"
recode CC334C (-3/3=0) (5=1) (*=1), gen(cantplaceobama)
label var cantplaceobama "Can't place Obama's ideology"
gen cantplaceeither=max(cantplaceromney,cantplaceobama)
label var cantplaceeither "Can't place Obama or Romney's ideology"

mean cantplaceobama
mean cantplaceromney

label var CC334A "Own Ideo Placement"
label var CC334D "Romney Ideo Placement"
label var CC334C "Obama Ideo Placement"

tab CC334D, gen(tid_)
tab CC334C, gen(cid_)
rename CC334A Ideology
tab Ideology, gen(ownideo_)
drop ownideo_4
rename Ideology ideo_own

rename CC334D ideo_romney
rename CC334C ideo_obama

// Ideological distance to each candidate

gen dist_obama = abs(ideo_obama-ideo_own) if ideo_obama~=5
label var dist_obama "Ideological Distance to Obama (0-6)"
gen dist_romney = abs(ideo_romney-ideo_own) if ideo_romney~=5
label var dist_romney "Ideological Distance to Romney (0-6)"

gen obamacloser=0
label var obamacloser "Obama closer to own ideology (1=yes)"
gen romneycloser=0
label var romneycloser "Romney closer to own ideology (1=yes)"
replace obamacloser = 1 if dist_obama<dist_romney & dist_obama~=. & dist_romney~=.
replace romneycloser = 1 if dist_romney<dist_obama & dist_obama~=. & dist_romney~=.

gen howmuchobamacloser=0
gen howmuchromneycloser=0
label var howmuchobamacloser "How much Obama closer than Romney (0 to 7)"
label var howmuchromneycloser "How much Romney closer than Obama (0 to 7)"

replace howmuchobamacloser = dist_romney - dist_obama if obamacloser==1
replace howmuchromneycloser = dist_obama - dist_romney if romneycloser==1

* weight
rename V103 commonweight_post

* Two analyzes are below, all of which are in the SI
* SI Table 4: Code first replicates our main finding from the body of the article using 2012 data (Avg Ideological placement and proportion of voters who cannot place) 
* Next, the code replicates SI Table 1 using 2012 data (Which candidate is closer and total distance)

qui if 1==1 {

//* SI Table Four, Replicating main finding using 2012 data **/

gen e_est = ""
gen e_cand = ""
gen e_sub =""
gen e_year = 2012
foreach var of newlist e_avg_place e_n e_avg_placeD e_nD e_avg_placeI e_nI e_avg_placeR e_nR {
	gen `var' = .
	}
label var e_avg_place "Overall"
label var e_avg_placeD "Among Dems."
label var e_avg_placeI "Among Indp."
label var e_avg_placeR "Among Reps."
label var e_n "N"
label var e_nD "N"
label var e_nI "N"
label var e_nR "N"

* Ideological Placement, 2012 -> Panel A in SI Table 4

* Candidate ideological placement
replace e_est = "Ideological Placement Table 4A Appendix" in 1/4
local inobs=1

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Democrat" in `inobs'
	replace e_sub = "Can Place Candidate" in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Candidate" in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceromney==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1


	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ ideo_romney [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	}

list e_* in 1/4

preserve
keep in 1/4
keep e_*
save Tables\SITable4A.dta, replace
restore

* Inability to Place Ideologically, 2012
* SI Table 4 Panel B

* Candidate ideological placement
replace e_est = "Can't Place Ideologically Table 4B Appendix" in 5/8

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ cantplaceobama [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ cantplaceromney [aweight=commonweight_post] 
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceromney [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceromney [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceromney [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place at least one candidate
	replace e_cand = "Democrat" in `inobs' 
	replace e_sub = "Can Place Other Candidate" in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplaceromney==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceobama [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1


	replace e_cand = "Republican" in `inobs'
	replace e_sub = "Can Place Other Candidate" in `inobs'
	summ cantplaceromney [aweight=commonweight_post] if cantplaceobama==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ cantplaceromney [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ cantplaceromney [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ cantplaceromney [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	}

list e_* in 5/8


preserve
keep in 5/8
keep e_*
save Tables\SITable4B.dta, replace
restore


//* SI Table Three Analysis **/

* Which candidate is closer in 2012? SI Table 3, Panel A

* Candidate ideological placement
replace e_est = "Closer to Candidate Table 3A" in 9/12

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Closer to Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ obamacloser [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Closer to Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ romneycloser [aweight=commonweight_post]
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ romneycloser [aweight=commonweight_post] if DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ romneycloser [aweight=commonweight_post] if DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ romneycloser [aweight=commonweight_post] if DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Closer to Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ obamacloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Closer to Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ romneycloser [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ romneycloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ romneycloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ romneycloser [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
}
list e_* in 9/12

preserve
keep in 9/12
keep e_*
save Tables\SITable3A.dta, replace
restore

* Candidate ideological placement
replace e_est = "Distance to Candidate Table 3B" in 13/18

qui if 1==1 {
	*Give can place candidate
	replace e_cand = "Distance to Democrat" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Overall" in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceromney==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceromney==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	*Given can place both candidates
	replace e_cand = "Distance to Democrat" in `inobs' 
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Can Place Both Candidates" in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceeither==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceeither==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
	
	*Given can't place other candidates
	replace e_cand = "Distance to Democrat" in `inobs' 
	replace e_sub = "Can't Place Other Candidate" in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplaceromney==1
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplaceromney==1 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplaceromney==1 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_obama [aweight=commonweight_post] if cantplaceobama==0 & cantplaceromney==1 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1

	replace e_cand = "Distance to Republican" in `inobs'
	replace e_sub = "Can't Place Other Candidate" in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceobama==1 & cantplaceromney==0
	replace e_avg_place=r(mean) in `inobs'
	replace e_n = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceobama==1 & cantplaceromney==0 & DtoItoR_pid3 == -1
	replace e_avg_placeD=r(mean) in `inobs'
	replace e_nD = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceobama==1 & cantplaceromney==0 & DtoItoR_pid3 == 0
	replace e_avg_placeI=r(mean) in `inobs'
	replace e_nI = r(N) in `inobs'
	summ dist_romney [aweight=commonweight_post] if cantplaceobama==1 & cantplaceromney==0 & DtoItoR_pid3 == 1
	replace e_avg_placeR=r(mean) in `inobs'
	replace e_nR = r(N) in `inobs'
	local inobs=`inobs' + 1
	
}

list e_* in 13/18

preserve
keep in 13/18
keep e_*
save Tables\SITable3B.dta, replace
restore

}

* table 4 in the appendix -> simple spatial models
reg obama_otherornon_romney obamacloser romneycloser 
outreg2 using Tables\Basic_Spatial2012.out, ctitle("Binary Indicators for Spatially Closer") se tdec(3) replace bracket

reg obama_otherornon_romney dist_obama dist_romney
outreg2 using Tables\Basic_Spatial2012.out, ctitle("Distance to Each Candidate") se tdec(3) append bracket

reg obama_otherornon_romney obamacloser romneycloser dist_obama dist_romney
outreg2 using Tables\Basic_Spatial2012.out, ctitle("Indicators and Distance") se tdec(3) append bracket
mean obama_otherornon_romney
